# -*- coding: utf-8 -*-

"""Top-level package for LDSA Grader."""

__author__ = """Hugo Castilho"""
__email__ = "hcastilho@lisbondatascience.org"
__version__ = "0.1.0"
